
The models in this directory were obtained from https://github.com/bdaiinstitute/spot_ros2.

They were modified in the following ways:
- use package paths to reference the assets
- add collision filter groups
